Index: wp-admin/admin-functions.php
===================================================================
--- wp-admin/admin-functions.php	(revision 1325)
+++ wp-admin/admin-functions.php	(working copy)
@@ -9,7 +9,7 @@
  * @subpackage Administration
  */
 
-_deprecated_file( basename(__FILE__), '2.5', 'wp-admin/includes/admin.php' );
+_deprecated_file( basename(__FILE__), 'wp-core', '2.5', 'wp-admin/includes/admin.php' );
 
 /** WordPress Administration API: Includes all Administration functions. */
 require_once(ABSPATH . 'wp-admin/includes/admin.php');
Index: wp-admin/includes/class-wp-filesystem-base.php
===================================================================
--- wp-admin/includes/class-wp-filesystem-base.php	(revision 1325)
+++ wp-admin/includes/class-wp-filesystem-base.php	(working copy)
@@ -99,7 +99,7 @@
 	 * @return string The location of the remote path.
 	 */
 	function find_base_dir($base = '.', $echo = false) {
-		_deprecated_function(__FUNCTION__, '2.7', 'WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir()' );
+		_deprecated_function( __FUNCTION__, 'wp-core', '2.7', 'WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir()' );
 		$this->verbose = $echo;
 		return $this->abspath();
 	}
@@ -117,7 +117,7 @@
 	 * @return string The location of the remote path.
 	 */
 	function get_base_dir($base = '.', $echo = false) {
-		_deprecated_function(__FUNCTION__, '2.7', 'WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir()' );
+		_deprecated_function( __FUNCTION__, 'wp-core', '2.7', 'WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir()' );
 		$this->verbose = $echo;
 		return $this->abspath();
 	}
Index: wp-admin/includes/deprecated.php
===================================================================
--- wp-admin/includes/deprecated.php	(revision 1509)
+++ wp-admin/includes/deprecated.php	(working copy)
@@ -19,7 +19,7 @@
  * @see wp_tiny_mce()
  */
 function tinymce_include() {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_tiny_mce()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_tiny_mce()' );
 
 	wp_tiny_mce();
 }
@@ -32,7 +32,7 @@
  *
  */
 function documentation_link() {
-	_deprecated_function( __FUNCTION__, '2.5', '' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', '' );
 	return;
 }
 
@@ -50,7 +50,7 @@
  * @return mixed Array(height,width) of shrunk dimensions.
  */
 function wp_shrink_dimensions( $width, $height, $wmax = 128, $hmax = 96 ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'wp_constrain_dimensions()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'wp_constrain_dimensions()' );
 	return wp_constrain_dimensions( $width, $height, $wmax, $hmax );
 }
 
@@ -67,7 +67,7 @@
  * @param unknown_type $popular_ids
  */
 function dropdown_categories( $default = 0, $parent = 0, $popular_ids = array() ) {
-	_deprecated_function( __FUNCTION__, '0.0', 'wp_category_checklist()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '0.0', 'wp_category_checklist()' );
 	global $post_ID;
 	wp_category_checklist( $post_ID );
 }
@@ -83,7 +83,7 @@
  * @param unknown_type $default
  */
 function dropdown_link_categories( $default = 0 ) {
-	_deprecated_function( __FUNCTION__, '0.0', 'wp_link_category_checklist()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '0.0', 'wp_link_category_checklist()' );
 	global $link_id;
 	wp_link_category_checklist( $link_id );
 }
@@ -104,7 +104,7 @@
  * @return unknown
  */
 function wp_dropdown_cats( $currentcat = 0, $currentparent = 0, $parent = 0, $level = 0, $categories = 0 ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'wp_dropdown_categories()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'wp_dropdown_categories()' );
 	if (!$categories )
 		$categories = get_categories( array('hide_empty' => 0) );
 
@@ -140,7 +140,7 @@
  * @return unknown
  */
 function add_option_update_handler( $option_group, $option_name, $sanitize_callback = '' ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'register_setting()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'register_setting()' );
 	return register_setting( $option_group, $option_name, $sanitize_callback );
 }
 
@@ -158,7 +158,7 @@
  * @return unknown
  */
 function remove_option_update_handler( $option_group, $option_name, $sanitize_callback = '' ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'unregister_setting()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'unregister_setting()' );
 	return unregister_setting( $option_group, $option_name, $sanitize_callback );
 }
 
@@ -171,7 +171,7 @@
  * @param string $filename
 **/
 function codepress_get_lang( $filename ) {
-	_deprecated_function( __FUNCTION__, '3.0' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0' );
 	return;
 }
 
@@ -182,7 +182,7 @@
  * @deprecated 3.0.0
 **/
 function codepress_footer_js() {
-	_deprecated_function( __FUNCTION__, '3.0' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0' );
 	return;
 }
 
@@ -193,7 +193,7 @@
  * @deprecated 3.0.0
 **/
 function use_codepress() {
-	_deprecated_function( __FUNCTION__, '3.0' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0' );
 	return;
 }
 
Index: wp-admin/includes/image.php
===================================================================
--- wp-admin/includes/image.php	(revision 1325)
+++ wp-admin/includes/image.php	(working copy)
@@ -22,7 +22,7 @@
  */
 function wp_create_thumbnail( $file, $max_side, $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '1.2' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '1.2' );
 	$thumbpath = image_resize( $file, $max_side, $max_side );
 	return apply_filters( 'wp_create_thumbnail', $thumbpath );
 }
Index: wp-admin/includes/meta-boxes.php
===================================================================
--- wp-admin/includes/meta-boxes.php	(revision 1325)
+++ wp-admin/includes/meta-boxes.php	(working copy)
@@ -703,7 +703,7 @@
 	global $link;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' ); // Never implemented
+		_deprecated_argument( __FUNCTION__, 'wp-core', '0.0' ); // Never implemented
 
 	$link_rel = isset( $link->link_rel ) ? $link->link_rel : ''; // In PHP 5.3: $link_rel = $link->link_rel ?: '';
 	$rels = preg_split('/\s+/', $link_rel);
Index: wp-admin/includes/ms-deprecated.php
===================================================================
--- wp-admin/includes/ms-deprecated.php	(revision 1325)
+++ wp-admin/includes/ms-deprecated.php	(working copy)
@@ -13,7 +13,7 @@
  * @deprecated 3.0.0
  */
 function wpmu_menu() {
-	_deprecated_function(__FUNCTION__, '3.0' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0' );
 	// deprecated. See #11763
 }
 
@@ -24,7 +24,7 @@
   * @see is_upload_space_available()
  */
 function wpmu_checkAvailableSpace() {
-	_deprecated_function(__FUNCTION__, '3.0', 'is_upload_space_available()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'is_upload_space_available()' );
 
 	if ( !is_upload_space_available() )
 		wp_die( __('Sorry, you must delete files before you can upload any more.') );
@@ -34,7 +34,7 @@
  * @deprecated 3.0.0
  */
 function mu_options( $options ) {
-	_deprecated_function(__FUNCTION__, '3.0' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0' );
 	return $options;
 }
 
@@ -43,7 +43,7 @@
  * @see activate_plugin()
  */
 function activate_sitewide_plugin() {
-	_deprecated_function(__FUNCTION__, '3.0', 'activate_plugin()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'activate_plugin()' );
 	return false;
 }
 
@@ -52,7 +52,7 @@
  * @see deactivate_sitewide_plugin()
  */
 function deactivate_sitewide_plugin( $plugin = false ) {
-	_deprecated_function(__FUNCTION__, '3.0', 'deactivate_plugin()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'deactivate_plugin()' );
 	return;
 }
 
@@ -61,7 +61,7 @@
  * @see is_network_only_plugin()
  */
 function is_wpmu_sitewide_plugin( $file ) {
-	_deprecated_function(__FUNCTION__, '3.0', 'is_network_only_plugin()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'is_network_only_plugin()' );
 	return is_network_only_plugin( $file );
 }
 
Index: wp-admin/includes/plugin.php
===================================================================
--- wp-admin/includes/plugin.php	(revision 1509)
+++ wp-admin/includes/plugin.php	(working copy)
@@ -89,7 +89,7 @@
 
 	// Site Wide Only is the old header for Network
 	if ( empty( $plugin_data['Network'] ) && ! empty( $plugin_data['_sitewide'] ) ) {
-		_deprecated_argument( __FUNCTION__, '3.0', sprintf( __( 'The <code>%1$s</code> plugin header is deprecated. Use <code>%2$s</code> instead.' ), 'Site Wide Only: true', 'Network: true' ) );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0', sprintf( __( 'The <code>%1$s</code> plugin header is deprecated. Use <code>%2$s</code> instead.' ), 'Site Wide Only: true', 'Network: true' ) );
 		$plugin_data['Network'] = $plugin_data['_sitewide'];
 	}
 	$plugin_data['Network'] = ( 'true' == strtolower( $plugin_data['Network'] ) );
@@ -1437,7 +1437,7 @@
 	global $new_whitelist_options;
 
 	if ( 'misc' == $option_group ) {
-		_deprecated_argument( __FUNCTION__, '3.0', __( 'The miscellaneous options group has been removed. Use another settings group.' ) );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0', __( 'The miscellaneous options group has been removed. Use another settings group.' ) );
 		$option_group = 'general';
 	}
 
@@ -1460,7 +1460,7 @@
 	global $new_whitelist_options;
 
 	if ( 'misc' == $option_group ) {
-		_deprecated_argument( __FUNCTION__, '3.0', __( 'The miscellaneous options group has been removed. Use another settings group.' ) );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0', __( 'The miscellaneous options group has been removed. Use another settings group.' ) );
 		$option_group = 'general';
 	}
 
Index: wp-admin/includes/template.php
===================================================================
--- wp-admin/includes/template.php	(revision 1325)
+++ wp-admin/includes/template.php	(working copy)
@@ -2982,7 +2982,7 @@
 	global $wp_settings_sections;
 
 	if ( 'misc' == $page ) {
-		_deprecated_argument( __FUNCTION__, '3.0', __( 'The miscellaneous options group has been removed. Use another settings group.' ) );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0', __( 'The miscellaneous options group has been removed. Use another settings group.' ) );
 		$page = 'general';
 	}
 
@@ -3022,7 +3022,7 @@
 	global $wp_settings_fields;
 
 	if ( 'misc' == $page ) {
-		_deprecated_argument( __FUNCTION__, '3.0', __( 'The miscellaneous options group has been removed. Use another settings group.' ) );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0', __( 'The miscellaneous options group has been removed. Use another settings group.' ) );
 		$page = 'general';
 	}
 
Index: wp-admin/includes/upgrade.php
===================================================================
--- wp-admin/includes/upgrade.php	(revision 1325)
+++ wp-admin/includes/upgrade.php	(working copy)
@@ -38,7 +38,7 @@
 	global $wp_rewrite;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.6' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.6' );
 
 	wp_check_mysql_version();
 	wp_cache_flush();
Index: wp-admin/upgrade-functions.php
===================================================================
--- wp-admin/upgrade-functions.php	(revision 1325)
+++ wp-admin/upgrade-functions.php	(working copy)
@@ -8,6 +8,6 @@
  * @subpackage Administration
  */
 
-_deprecated_file( basename(__FILE__), '2.5', 'wp-admin/includes/upgrade.php' );
+_deprecated_file( basename(__FILE__), 'wp-core', '2.5', 'wp-admin/includes/upgrade.php' );
 require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
 ?>
Index: wp-app.php
===================================================================
--- wp-app.php	(revision 1513)
+++ wp-app.php	(working copy)
@@ -871,7 +871,7 @@
 	 */
 	function get_categories_url($deprecated = '') {
 		if ( !empty( $deprecated ) )
-			_deprecated_argument( __FUNCTION__, '2.5' );
+			_deprecated_argument( __FUNCTION__, 'wp-core', '2.5' );
 		return $this->app_base . $this->CATEGORIES_PATH;
 	}
 
Index: wp-includes/author-template.php
===================================================================
--- wp-includes/author-template.php	(revision 1326)
+++ wp-includes/author-template.php	(working copy)
@@ -24,7 +24,7 @@
 	global $authordata;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.1' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.1' );
 
 	return apply_filters('the_author', is_object($authordata) ? $authordata->display_name : null);
 }
@@ -50,9 +50,9 @@
  */
 function the_author( $deprecated = '', $deprecated_echo = true ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.1' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.1' );
 	if ( $deprecated_echo !== true )
-		_deprecated_argument( __FUNCTION__, '1.5', __('Use <code>get_the_author()</code> instead if you do not want the value echoed.') );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '1.5', __('Use <code>get_the_author()</code> instead if you do not want the value echoed.') );
 	if ( $deprecated_echo )
 		echo get_the_author();
 	return get_the_author();
@@ -198,7 +198,7 @@
  */
 function the_author_posts_link($deprecated = '') {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.1' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.1' );
 
 	global $authordata;
 	$link = sprintf(
Index: wp-includes/capabilities.php
===================================================================
--- wp-includes/capabilities.php	(revision 1326)
+++ wp-includes/capabilities.php	(working copy)
@@ -719,7 +719,7 @@
 	 */
 	function has_cap( $cap ) {
 		if ( is_numeric( $cap ) ) {
-			_deprecated_argument( __FUNCTION__, '2.0', __('Usage of user levels by plugins and themes is deprecated. Use roles and capabilities instead.') );
+			_deprecated_argument( __FUNCTION__, 'wp-core', '2.0', __('Usage of user levels by plugins and themes is deprecated. Use roles and capabilities instead.') );
 			$cap = $this->translate_level_to_cap( $cap );
 		}
 
Index: wp-includes/category-template.php
===================================================================
--- wp-includes/category-template.php	(revision 1326)
+++ wp-includes/category-template.php	(working copy)
@@ -351,7 +351,7 @@
 
 	// Back compat.
 	if ( isset( $args['type'] ) && 'link' == $args['type'] ) {
-		_deprecated_argument( __FUNCTION__, '3.0', '' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0', '' );
 		$args['taxonomy'] = 'link_category';
 	}
 
Index: wp-includes/category.php
===================================================================
--- wp-includes/category.php	(revision 1326)
+++ wp-includes/category.php	(working copy)
@@ -44,7 +44,7 @@
 
 	// Back compat
 	if ( isset($args['type']) && 'link' == $args['type'] ) {
-		_deprecated_argument( __FUNCTION__, '3.0', '' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0', '' );
 		$taxonomy = $args['taxonomy'] = 'link_category';
 	}
 
Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 1326)
+++ wp-includes/comment-template.php	(working copy)
@@ -529,9 +529,9 @@
  */
 function comments_link( $deprecated = '', $deprecated_2 = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.72' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '0.72' );
 	if ( !empty( $deprecated_2 ) )
-		_deprecated_argument( __FUNCTION__, '1.3' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '1.3' );
 	echo get_comments_link();
 }
 
@@ -576,7 +576,7 @@
 	global $id;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '1.3' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '1.3' );
 
 	$number = get_comments_number($id);
 
@@ -728,7 +728,7 @@
  */
 function trackback_url( $deprecated_echo = true ) {
 	if ( $deprecated_echo !== true )
-		_deprecated_argument( __FUNCTION__, '2.5', __('Use <code>get_trackback_url()</code> instead if you do not want the value echoed.') );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.5', __('Use <code>get_trackback_url()</code> instead if you do not want the value echoed.') );
 	if ( $deprecated_echo )
 		echo get_trackback_url();
 	else
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 1326)
+++ wp-includes/comment.php	(working copy)
@@ -1525,7 +1525,7 @@
  */
 function discover_pingback_server_uri( $url, $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.7' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.7' );
 
 	$pingback_str_dquote = 'rel="pingback"';
 	$pingback_str_squote = 'rel=\'pingback\'';
Index: wp-includes/cron.php
===================================================================
--- wp-includes/cron.php	(revision 1326)
+++ wp-includes/cron.php	(working copy)
@@ -136,7 +136,7 @@
 	// Backward compatibility
 	// Previously this function took the arguments as discrete vars rather than an array like the rest of the API
 	if ( !is_array($args) ) {
-		_deprecated_argument( __FUNCTION__, '3.0.0', __('This argument has changed to an array to match the behavior of the other cron functions.') );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0.0', __('This argument has changed to an array to match the behavior of the other cron functions.') );
 		$args = array_slice( func_get_args(), 1 );
 	}
 
Index: wp-includes/deprecated.php
===================================================================
--- wp-includes/deprecated.php	(revision 1326)
+++ wp-includes/deprecated.php	(working copy)
@@ -24,7 +24,7 @@
  * @return array
  */
 function get_postdata($postid) {
-	_deprecated_function( __FUNCTION__, '1.5.1', 'get_post()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '1.5.1', 'get_post()' );
 
 	$post = &get_post($postid);
 
@@ -59,7 +59,7 @@
 function start_wp() {
 	global $wp_query, $post;
 
-	_deprecated_function( __FUNCTION__, '1.5', __('new WordPress Loop') );
+	_deprecated_function( __FUNCTION__, 'wp-core', '1.5', __('new WordPress Loop') );
 
 	// Since the old style loop is being used, advance the query iterator here.
 	$wp_query->next_post();
@@ -79,7 +79,7 @@
  * @return null|int
  */
 function the_category_ID($echo = true) {
-	_deprecated_function( __FUNCTION__, '0.71', 'get_the_category()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '0.71', 'get_the_category()' );
 
 	// Grab the first cat in the list.
 	$categories = get_the_category();
@@ -105,7 +105,7 @@
 function the_category_head($before='', $after='') {
 	global $currentcat, $previouscat;
 
-	_deprecated_function( __FUNCTION__, '0.71', 'get_the_category_by_ID()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '0.71', 'get_the_category_by_ID()' );
 
 	// Grab the first cat in the list.
 	$categories = get_the_category();
@@ -135,7 +135,7 @@
  */
 function previous_post($format='%', $previous='previous post: ', $title='yes', $in_same_cat='no', $limitprev=1, $excluded_categories='') {
 
-	_deprecated_function( __FUNCTION__, '2.0', 'previous_post_link()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'previous_post_link()' );
 
 	if ( empty($in_same_cat) || 'no' == $in_same_cat )
 		$in_same_cat = false;
@@ -171,7 +171,7 @@
  * @param string $excluded_categories
  */
 function next_post($format='%', $next='next post: ', $title='yes', $in_same_cat='no', $limitnext=1, $excluded_categories='') {
-	_deprecated_function( __FUNCTION__, '2.0', 'next_post_link()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'next_post_link()' );
 
 	if ( empty($in_same_cat) || 'no' == $in_same_cat )
 		$in_same_cat = false;
@@ -205,7 +205,7 @@
  * @return bool
  */
 function user_can_create_post($user_id, $blog_id = 1, $category_id = 'None') {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	$author_data = get_userdata($user_id);
 	return ($author_data->user_level > 1);
@@ -225,7 +225,7 @@
  * @return bool
  */
 function user_can_create_draft($user_id, $blog_id = 1, $category_id = 'None') {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	$author_data = get_userdata($user_id);
 	return ($author_data->user_level >= 1);
@@ -245,7 +245,7 @@
  * @return bool
  */
 function user_can_edit_post($user_id, $post_id, $blog_id = 1) {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	$author_data = get_userdata($user_id);
 	$post = get_post($post_id);
@@ -274,7 +274,7 @@
  * @return bool
  */
 function user_can_delete_post($user_id, $post_id, $blog_id = 1) {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	// right now if one can edit, one can delete
 	return user_can_edit_post($user_id, $post_id, $blog_id);
@@ -294,7 +294,7 @@
  * @return bool
  */
 function user_can_set_post_date($user_id, $blog_id = 1, $category_id = 'None') {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	$author_data = get_userdata($user_id);
 	return (($author_data->user_level > 4) && user_can_create_post($user_id, $blog_id, $category_id));
@@ -314,7 +314,7 @@
  * @return bool returns true if $user_id can edit $post_id's date
  */
 function user_can_edit_post_date($user_id, $post_id, $blog_id = 1) {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	$author_data = get_userdata($user_id);
 	return (($author_data->user_level > 4) && user_can_edit_post($user_id, $post_id, $blog_id));
@@ -334,7 +334,7 @@
  * @return bool returns true if $user_id can edit $post_id's comments
  */
 function user_can_edit_post_comments($user_id, $post_id, $blog_id = 1) {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	// right now if one can edit a post, one can edit comments made on it
 	return user_can_edit_post($user_id, $post_id, $blog_id);
@@ -354,7 +354,7 @@
  * @return bool returns true if $user_id can delete $post_id's comments
  */
 function user_can_delete_post_comments($user_id, $post_id, $blog_id = 1) {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	// right now if one can edit comments, one can delete comments
 	return user_can_edit_post_comments($user_id, $post_id, $blog_id);
@@ -373,7 +373,7 @@
  * @return bool
  */
 function user_can_edit_user($user_id, $other_user) {
-	_deprecated_function( __FUNCTION__, '2.0', 'current_user_can()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'current_user_can()' );
 
 	$user  = get_userdata($user_id);
 	$other = get_userdata($other_user);
@@ -407,7 +407,7 @@
 function get_linksbyname($cat_name = "noname", $before = '', $after = '<br />', $between = " ", $show_images = true, $orderby = 'id',
 						 $show_description = true, $show_rating = false,
 						 $limit = -1, $show_updated = 0) {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_bookmarks()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_bookmarks()' );
 
 	$cat_id = -1;
 	$cat = get_term_by('name', $cat_name, 'link_category');
@@ -471,7 +471,7 @@
  * @return unknown
  */
 function get_linkobjectsbyname($cat_name = "noname" , $orderby = 'name', $limit = -1) {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_bookmarks()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_bookmarks()' );
 
 	$cat_id = -1;
 	$cat = get_term_by('name', $cat_name, 'link_category');
@@ -525,7 +525,7 @@
  * @return unknown
  */
 function get_linkobjects($category = 0, $orderby = 'name', $limit = 0) {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_bookmarks()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_bookmarks()' );
 
 	$links = get_bookmarks( array( 'category' => $category, 'orderby' => $orderby, 'limit' => $limit ) ) ;
 
@@ -559,7 +559,7 @@
  */
 function get_linksbyname_withrating($cat_name = "noname", $before = '', $after = '<br />', $between = " ",
 									$show_images = true, $orderby = 'id', $show_description = true, $limit = -1, $show_updated = 0) {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_bookmarks()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_bookmarks()' );
 
 	get_linksbyname($cat_name, $before, $after, $between, $show_images, $orderby, $show_description, true, $limit, $show_updated);
 }
@@ -587,7 +587,7 @@
  */
 function get_links_withrating($category = -1, $before = '', $after = '<br />', $between = " ", $show_images = true,
 							  $orderby = 'id', $show_description = true, $limit = -1, $show_updated = 0) {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_bookmarks()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_bookmarks()' );
 
 	get_links($category, $before, $after, $between, $show_images, $orderby, $show_description, true, $limit, $show_updated);
 }
@@ -603,7 +603,7 @@
  * @return int Only returns 0.
  */
 function get_autotoggle($id = 0) {
-	_deprecated_function( __FUNCTION__, '2.1' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1' );
 	return 0;
 }
 
@@ -636,7 +636,7 @@
 function list_cats($optionall = 1, $all = 'All', $sort_column = 'ID', $sort_order = 'asc', $file = '', $list = true, $optiondates = 0,
 				   $optioncount = 0, $hide_empty = 1, $use_desc_for_title = 1, $children=false, $child_of=0, $categories=0,
 				   $recurse=0, $feed = '', $feed_image = '', $exclude = '', $hierarchical=false) {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_list_categories()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_list_categories()' );
 
 	$query = compact('optionall', 'all', 'sort_column', 'sort_order', 'file', 'list', 'optiondates', 'optioncount', 'hide_empty', 'use_desc_for_title', 'children',
 		'child_of', 'categories', 'recurse', 'feed', 'feed_image', 'exclude', 'hierarchical');
@@ -653,7 +653,7 @@
  * @return unknown
  */
 function wp_list_cats($args = '') {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_list_categories()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_list_categories()' );
 
 	$r = wp_parse_args( $args );
 
@@ -696,7 +696,7 @@
 function dropdown_cats($optionall = 1, $all = 'All', $orderby = 'ID', $order = 'asc',
 		$show_last_update = 0, $show_count = 0, $hide_empty = 1, $optionnone = false,
 		$selected = 0, $exclude = 0) {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_dropdown_categories()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_dropdown_categories()' );
 
 	$show_option_all = '';
 	if ( $optionall )
@@ -727,7 +727,7 @@
  * @return unknown
  */
 function list_authors($optioncount = false, $exclude_admin = true, $show_fullname = false, $hide_empty = true, $feed = '', $feed_image = '') {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_list_authors()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_list_authors()' );
 
 	$args = compact('optioncount', 'exclude_admin', 'show_fullname', 'hide_empty', 'feed', 'feed_image');
 	return wp_list_authors($args);
@@ -744,7 +744,7 @@
  * @return unknown
  */
 function wp_get_post_cats($blogid = '1', $post_ID = 0) {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_get_post_categories()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_get_post_categories()' );
 	return wp_get_post_categories($post_ID);
 }
 
@@ -762,7 +762,7 @@
  * @return unknown
  */
 function wp_set_post_cats($blogid = '1', $post_ID = 0, $post_categories = array()) {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_set_post_categories()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_set_post_categories()' );
 	return wp_set_post_categories($post_ID, $post_categories);
 }
 
@@ -781,7 +781,7 @@
  * @return unknown
  */
 function get_archives($type='', $limit='', $format='html', $before = '', $after = '', $show_post_count = false) {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_get_archives()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_get_archives()' );
 	$args = compact('type', 'limit', 'format', 'before', 'after', 'show_post_count');
 	return wp_get_archives($args);
 }
@@ -800,7 +800,7 @@
  * @return string|null
  */
 function get_author_link($echo = false, $author_id, $author_nicename = '') {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_author_posts_url()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_author_posts_url()' );
 
 	$link = get_author_posts_url($author_id, $author_nicename);
 
@@ -828,7 +828,7 @@
  */
 function link_pages($before='<br />', $after='<br />', $next_or_number='number', $nextpagelink='next page', $previouspagelink='previous page',
 					$pagelink='%', $more_file='') {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_link_pages()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_link_pages()' );
 
 	$args = compact('before', 'after', 'next_or_number', 'nextpagelink', 'previouspagelink', 'pagelink', 'more_file');
 	return wp_link_pages($args);
@@ -846,7 +846,7 @@
  * @return string
  */
 function get_settings($option) {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_option()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_option()' );
 
 	return get_option($option);
 }
@@ -860,7 +860,7 @@
  * @see the_permalink()
  */
 function permalink_link() {
-	_deprecated_function( __FUNCTION__, '1.2', 'the_permalink()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '1.2', 'the_permalink()' );
 	the_permalink();
 }
 
@@ -875,7 +875,7 @@
  * @param string $file
  */
 function permalink_single_rss($deprecated = '') {
-	_deprecated_function( __FUNCTION__, '0.0', 'the_permalink_rss()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '0.0', 'the_permalink_rss()' );
 	the_permalink_rss();
 }
 
@@ -892,7 +892,7 @@
  * @return null|string
  */
 function wp_get_links($args = '') {
-	_deprecated_function( __FUNCTION__, '0.0', 'wp_list_bookmarks()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '0.0', 'wp_list_bookmarks()' );
 
 	if ( strpos( $args, '=' ) === false ) {
 		$cat_id = $args;
@@ -947,7 +947,7 @@
  */
 function get_links($category = -1, $before = '', $after = '<br />', $between = ' ', $show_images = true, $orderby = 'name',
 			$show_description = true, $show_rating = false, $limit = -1, $show_updated = 1, $echo = true) {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_bookmarks()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_bookmarks()' );
 
 	$order = 'ASC';
 	if ( substr($orderby, 0, 1) == '_' ) {
@@ -1040,7 +1040,7 @@
  * @param string $order Sort link categories by 'name' or 'id'
  */
 function get_links_list($order = 'name') {
-	_deprecated_function( __FUNCTION__, '2.1', 'wp_list_bookmarks()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'wp_list_bookmarks()' );
 
 	$order = strtolower($order);
 
@@ -1086,7 +1086,7 @@
  * @param bool $count the number of links in the db
  */
 function links_popup_script($text = 'Links', $width=400, $height=400, $file='links.all.php', $count = true) {
-	_deprecated_function( __FUNCTION__, '2.1' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1' );
 
 	if ( $count )
 		$counts = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->links");
@@ -1111,7 +1111,7 @@
  * @return unknown
  */
 function get_linkrating($link) {
-	_deprecated_function( __FUNCTION__, '2.1', 'sanitize_bookmark_field()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'sanitize_bookmark_field()' );
 	return sanitize_bookmark_field('link_rating', $link->link_rating, $link->link_id, 'display');
 }
 
@@ -1127,7 +1127,7 @@
  * @return string
  */
 function get_linkcatname($id = 0) {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_category()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_category()' );
 
 	$id = (int) $id;
 
@@ -1156,7 +1156,7 @@
  * @param string $link_text
  */
 function comments_rss_link($link_text = 'Comments RSS') {
-	_deprecated_function( __FUNCTION__, '2.5', 'post_comments_feed_link()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'post_comments_feed_link()' );
 	post_comments_feed_link($link_text);
 }
 
@@ -1173,7 +1173,7 @@
  * @return string|null
  */
 function get_category_rss_link($echo = false, $cat_ID = 1) {
-	_deprecated_function( __FUNCTION__, '2.5', 'get_category_feed_link()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'get_category_feed_link()' );
 
 	$link = get_category_feed_link($cat_ID, 'rss2');
 
@@ -1195,7 +1195,7 @@
  * @return string|null
  */
 function get_author_rss_link($echo = false, $author_id = 1) {
-	_deprecated_function( __FUNCTION__, '2.5', 'get_author_feed_link()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'get_author_feed_link()' );
 
 	$link = get_author_feed_link($author_id);
 	if ( $echo )
@@ -1214,7 +1214,7 @@
  * @return string
  */
 function comments_rss() {
-	_deprecated_function( __FUNCTION__, '2.2', 'get_post_comments_feed_link()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.2', 'get_post_comments_feed_link()' );
 	return get_post_comments_feed_link();
 }
 
@@ -1232,7 +1232,7 @@
  * @return int The new user's ID.
  */
 function create_user($username, $password, $email) {
-	_deprecated_function( __FUNCTION__, '2.0', 'wp_create_user()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.0', 'wp_create_user()' );
 	return wp_create_user($username, $password, $email);
 }
 
@@ -1242,7 +1242,7 @@
  * @deprecated 2.5
 */
 function gzip_compression() {
-	_deprecated_function( __FUNCTION__, '2.5' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5' );
 	return false;
 }
 
@@ -1260,7 +1260,7 @@
  * @return array The comment data
  */
 function get_commentdata( $comment_ID, $no_cache = 0, $include_unapproved = false ) {
-	_deprecated_function( __FUNCTION__, '2.7', 'get_comment()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.7', 'get_comment()' );
 	return get_comment($comment_ID, ARRAY_A);
 }
 
@@ -1276,7 +1276,7 @@
  * @return string category name
  */
 function get_catname( $cat_ID ) {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_cat_name()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_cat_name()' );
 	return get_cat_name( $cat_ID );
 }
 
@@ -1295,7 +1295,7 @@
  * @return string
  */
 function get_category_children( $id, $before = '/', $after = '', $visited = array() ) {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_term_children()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_term_children()' );
 	if ( 0 == $id )
 		return '';
 
@@ -1329,7 +1329,7 @@
  * @return string The author's description.
  */
 function get_the_author_description() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'description\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'description\')' );
 	return get_the_author_meta('description');
 }
 
@@ -1342,7 +1342,7 @@
  * @see the_author_meta()
  */
 function the_author_description() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'description\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'description\')' );
 	the_author_meta('description');
 }
 
@@ -1357,7 +1357,7 @@
  * @return string The author's login name (username).
  */
 function get_the_author_login() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'login\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'login\')' );
 	return get_the_author_meta('login');
 }
 
@@ -1370,7 +1370,7 @@
  * @see the_author_meta()
  */
 function the_author_login() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'login\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'login\')' );
 	the_author_meta('login');
 }
 
@@ -1385,7 +1385,7 @@
  * @return string The author's first name.
  */
 function get_the_author_firstname() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'first_name\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'first_name\')' );
 	return get_the_author_meta('first_name');
 }
 
@@ -1398,7 +1398,7 @@
  * @see the_author_meta()
  */
 function the_author_firstname() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'first_name\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'first_name\')' );
 	the_author_meta('first_name');
 }
 
@@ -1413,7 +1413,7 @@
  * @return string The author's last name.
  */
 function get_the_author_lastname() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'last_name\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'last_name\')' );
 	return get_the_author_meta('last_name');
 }
 
@@ -1426,7 +1426,7 @@
  * @see the_author_meta()
  */
 function the_author_lastname() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'last_name\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'last_name\')' );
 	the_author_meta('last_name');
 }
 
@@ -1441,7 +1441,7 @@
  * @return string The author's nickname.
  */
 function get_the_author_nickname() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'nickname\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'nickname\')' );
 	return get_the_author_meta('nickname');
 }
 
@@ -1454,7 +1454,7 @@
  * @see the_author_meta()
  */
 function the_author_nickname() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'nickname\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'nickname\')' );
 	the_author_meta('nickname');
 }
 
@@ -1469,7 +1469,7 @@
  * @return string The author's username.
  */
 function get_the_author_email() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'email\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'email\')' );
 	return get_the_author_meta('email');
 }
 
@@ -1482,7 +1482,7 @@
  * @see the_author_meta()
  */
 function the_author_email() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'email\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'email\')' );
 	the_author_meta('email');
 }
 
@@ -1497,7 +1497,7 @@
  * @return string The author's ICQ number.
  */
 function get_the_author_icq() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'icq\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'icq\')' );
 	return get_the_author_meta('icq');
 }
 
@@ -1510,7 +1510,7 @@
  * @see the_author_meta()
  */
 function the_author_icq() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'icq\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'icq\')' );
 	the_author_meta('icq');
 }
 
@@ -1525,7 +1525,7 @@
  * @return string The author's Yahoo! IM name.
  */
 function get_the_author_yim() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'yim\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'yim\')' );
 	return get_the_author_meta('yim');
 }
 
@@ -1538,7 +1538,7 @@
  * @see the_author_meta()
  */
 function the_author_yim() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'yim\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'yim\')' );
 	the_author_meta('yim');
 }
 
@@ -1553,7 +1553,7 @@
  * @return string The author's MSN address.
  */
 function get_the_author_msn() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'msn\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'msn\')' );
 	return get_the_author_meta('msn');
 }
 
@@ -1566,7 +1566,7 @@
  * @see the_author_meta()
  */
 function the_author_msn() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'msn\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'msn\')' );
 	the_author_meta('msn');
 }
 
@@ -1581,7 +1581,7 @@
  * @return string The author's AIM address.
  */
 function get_the_author_aim() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'aim\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'aim\')' );
 	return get_the_author_meta('aim');
 }
 
@@ -1594,7 +1594,7 @@
  * @deprecated Use the_author_meta('aim')
  */
 function the_author_aim() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'aim\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'aim\')' );
 	the_author_meta('aim');
 }
 
@@ -1610,7 +1610,7 @@
  * @return string The author's display name.
  */
 function get_author_name( $auth_id = false ) {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'display_name\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'display_name\')' );
 	return get_the_author_meta('display_name', $auth_id);
 }
 
@@ -1625,7 +1625,7 @@
  * @return string The URL to the author's page.
  */
 function get_the_author_url() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'url\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'url\')' );
 	return get_the_author_meta('url');
 }
 
@@ -1638,7 +1638,7 @@
  * @see the_author_meta()
  */
 function the_author_url() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'url\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'url\')' );
 	the_author_meta('url');
 }
 
@@ -1653,7 +1653,7 @@
  * @return int The author's ID.
  */
 function get_the_author_ID() {
-	_deprecated_function( __FUNCTION__, '2.8', 'get_the_author_meta(\'ID\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'get_the_author_meta(\'ID\')' );
 	return get_the_author_meta('ID');
 }
 
@@ -1666,7 +1666,7 @@
  * @see the_author_meta()
 */
 function the_author_ID() {
-	_deprecated_function( __FUNCTION__, '2.8', 'the_author_meta(\'ID\')' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'the_author_meta(\'ID\')' );
 	the_author_meta('ID');
 }
 
@@ -1705,7 +1705,7 @@
  * @param int $encode_html Optional. How to encode the content.
  */
 function the_content_rss($more_link_text='(more...)', $stripteaser=0, $more_file='', $cut = 0, $encode_html = 0) {
-	_deprecated_function( __FUNCTION__, '2.9', 'the_content_feed' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.9', 'the_content_feed' );
 	$content = get_the_content($more_link_text, $stripteaser, $more_file);
 	$content = apply_filters('the_content_rss', $content);
 	if ( $cut && !$encode_html )
@@ -1751,7 +1751,7 @@
  * @return string HTML stripped out of content with links at the bottom.
  */
 function make_url_footnote( $content ) {
-	_deprecated_function( __FUNCTION__, '2.9', '' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.9', '' );
 	preg_match_all( '/<a(.+?)href=\"(.+?)\"(.*?)>(.+?)<\/a>/', $content, $matches );
 	$links_summary = "\n";
 	for ( $i=0; $i<count($matches[0]); $i++ ) {
@@ -1791,7 +1791,7 @@
  * @return string Translated context string without pipe
  */
 function _c( $text, $domain = 'default' ) {
-	_deprecated_function( __FUNCTION__, '2.9', '_x()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.9', '_x()' );
 	return before_last_bar( translate( $text, $domain ) );
 }
 
@@ -1810,7 +1810,7 @@
  * @return string Translated text
  */
 function translate_with_context( $text, $domain = 'default' ) {
-	_deprecated_function( __FUNCTION__, '2.9', '_x()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.9', '_x()' );
 	return before_last_bar( translate( $text, $domain ) );
 }
 
@@ -1827,7 +1827,7 @@
  *
  */
 function _nc( $single, $plural, $number, $domain = 'default' ) {
-	_deprecated_function( __FUNCTION__, '2.9', '_nx()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.9', '_nx()' );
 	return before_last_bar( _n( $single, $plural, $number, $domain ) );
 }
 
@@ -1840,7 +1840,7 @@
  * @see _n()
  */
 function __ngettext() {
-	_deprecated_function( __FUNCTION__, '2.8', '_n()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', '_n()' );
 	$args = func_get_args();
 	return call_user_func_array('_n', $args);
 }
@@ -1854,7 +1854,7 @@
  * @see _n_noop()
  */
 function __ngettext_noop() {
-	_deprecated_function( __FUNCTION__, '2.8', '_n_noop()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', '_n_noop()' );
 	$args = func_get_args();
 	return call_user_func_array('_n_noop', $args);
 
@@ -1871,7 +1871,7 @@
  * @return array List of all options.
  */
 function get_alloptions() {
-	_deprecated_function( __FUNCTION__, '3.0', 'wp_load_alloptions()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'wp_load_alloptions()' );
 	return wp_load_alloptions();
 }
 
@@ -1890,7 +1890,7 @@
  * @return string
  */
 function get_the_attachment_link($id = 0, $fullsize = false, $max_dims = false, $permalink = false) {
-	_deprecated_function( __FUNCTION__, '2.5', 'wp_get_attachment_link()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'wp_get_attachment_link()' );
 	$id = (int) $id;
 	$_post = & get_post($id);
 
@@ -1919,7 +1919,7 @@
  * @return array Icon URL and full path to file, respectively.
  */
 function get_attachment_icon_src( $id = 0, $fullsize = false ) {
-	_deprecated_function( __FUNCTION__, '2.5', 'wp_get_attachment_image_src()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'wp_get_attachment_image_src()' );
 	$id = (int) $id;
 	if ( !$post = & get_post($id) )
 		return false;
@@ -1964,7 +1964,7 @@
  * @return string HTML content.
  */
 function get_attachment_icon( $id = 0, $fullsize = false, $max_dims = false ) {
-	_deprecated_function( __FUNCTION__, '2.5', 'wp_get_attachment_image()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'wp_get_attachment_image()' );
 	$id = (int) $id;
 	if ( !$post = & get_post($id) )
 		return false;
@@ -2021,7 +2021,7 @@
  * @return string
  */
 function get_attachment_innerHTML($id = 0, $fullsize = false, $max_dims = false) {
-	_deprecated_function( __FUNCTION__, '2.5', 'wp_get_attachment_image()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'wp_get_attachment_image()' );
 	$id = (int) $id;
 	if ( !$post = & get_post($id) )
 		return false;
@@ -2048,7 +2048,7 @@
  * @return object|array
  */
 function get_link($bookmark_id, $output = OBJECT, $filter = 'raw') {
-	_deprecated_function( __FUNCTION__, '2.1', 'get_bookmark()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.1', 'get_bookmark()' );
 	return get_bookmark($bookmark_id, $output, $filter);
 }
 
@@ -2065,7 +2065,7 @@
  * @return string The cleaned URL.
  */
 function sanitize_url( $url, $protocols = null ) {
-	_deprecated_function( __FUNCTION__, '2.8', 'esc_url_raw()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'esc_url_raw()' );
 	return esc_url_raw( $url, $protocols );
 }
 
@@ -2090,7 +2090,7 @@
 	if ( $context == 'db' )
 		_deprecated_function( 'clean_url( $context = \'db\' )', '3.0', 'esc_url_raw()' );
 	else
-		_deprecated_function( __FUNCTION__, '3.0', 'esc_url()' );
+		_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'esc_url()' );
 	return esc_url( $url, $protocols, $context );
 }
 
@@ -2108,7 +2108,7 @@
  * @return string Escaped text.
  */
 function js_escape( $text ) {
-	_deprecated_function( __FUNCTION__, '2.8', 'esc_js()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'esc_js()' );
 	return esc_js( $text );
 }
 
@@ -2120,7 +2120,7 @@
  * @see esc_html()
  */
 function wp_specialchars( $string, $quote_style = ENT_NOQUOTES, $charset = false, $double_encode = false ) {
-	_deprecated_function( __FUNCTION__, '2.8', 'esc_html()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'esc_html()' );
 	if ( func_num_args() > 1 ) { // Maintain backwards compat for people passing additional args
 		$args = func_get_args();
 		return call_user_func_array( '_wp_specialchars', $args );
@@ -2142,7 +2142,7 @@
  * @return string
  */
 function attribute_escape( $text ) {
-	_deprecated_function( __FUNCTION__, '2.8', 'esc_attr()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'esc_attr()' );
 	return esc_attr( $text );
 }
 
@@ -2167,7 +2167,7 @@
  * @param mixed $params,... Widget parameters.
  */
 function register_sidebar_widget($name, $output_callback, $classname = '') {
-	_deprecated_function( __FUNCTION__, '2.8', 'wp_register_sidebar_widget()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'wp_register_sidebar_widget()' );
 	// Compat
 	if ( is_array($name) ) {
 		if ( count($name) == 3 )
@@ -2199,7 +2199,7 @@
  * @param int|string $id Widget ID.
  */
 function unregister_sidebar_widget($id) {
-	_deprecated_function( __FUNCTION__, '2.8', 'wp_unregister_sidebar_widget()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'wp_unregister_sidebar_widget()' );
 	return wp_unregister_sidebar_widget($id);
 }
 
@@ -2224,7 +2224,7 @@
  * @param int $height Widget height.
  */
 function register_widget_control($name, $control_callback, $width = '', $height = '') {
-	_deprecated_function( __FUNCTION__, '2.8', 'wp_register_widget_control()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'wp_register_widget_control()' );
 	// Compat
 	if ( is_array($name) ) {
 		if ( count($name) == 3 )
@@ -2258,7 +2258,7 @@
  * @param int|string $id Widget ID.
  */
 function unregister_widget_control($id) {
-	_deprecated_function( __FUNCTION__, '2.8', 'wp_unregister_widget_control()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.8', 'wp_unregister_widget_control()' );
 	return wp_unregister_widget_control($id);
 }
 
@@ -2276,7 +2276,7 @@
  * @return bool True deletion completed and false if user_id is not a number.
  */
 function delete_usermeta( $user_id, $meta_key, $meta_value = '' ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'delete_user_meta()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'delete_user_meta()' );
 	global $wpdb;
 	if ( !is_numeric( $user_id ) )
 		return false;
@@ -2322,7 +2322,7 @@
  * @return mixed
  */
 function get_usermeta( $user_id, $meta_key = '' ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'get_user_meta()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'get_user_meta()' );
 	global $wpdb;
 	$user_id = (int) $user_id;
 
@@ -2376,7 +2376,7 @@
  * @return bool True on successful update, false on failure.
  */
 function update_usermeta( $user_id, $meta_key, $meta_value ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'update_user_meta()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'update_user_meta()' );
 	global $wpdb;
 	if ( !is_numeric( $user_id ) )
 		return false;
@@ -2423,7 +2423,7 @@
  * @param boolean $add Optional, default is true. Add or remove links. Defaults to true.
  */
 function automatic_feed_links( $add = true ) {
-	_deprecated_function( __FUNCTION__, '3.0', "add_theme_support( 'automatic-feed-links' )" );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', "add_theme_support( 'automatic-feed-links' )" );
 
 	if ( $add )
 		add_theme_support( 'automatic-feed-links' );
@@ -2440,7 +2440,7 @@
  * @see get_the_author_meta()
  */
 function get_profile( $field, $user = false ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'get_the_author_meta()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'get_the_author_meta()' );
 	if ( $user ) {
 		$user = get_user_by( 'login', $user );
 		$user = $user->ID;
@@ -2457,7 +2457,7 @@
  * @see count_user_posts()
  */
 function get_usernumposts( $userid ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'count_user_posts()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'count_user_posts()' );
 	return count_user_posts( $userid );
 }
 
@@ -2489,7 +2489,7 @@
  * @return string Fixed text.
  */
 function funky_javascript_fix($text) {
-	_deprecated_function( __FUNCTION__, '3.0' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0' );
 	// Fixes for browsers' javascript bugs
 	global $is_macIE, $is_winIE;
 
@@ -2510,6 +2510,6 @@
  * @param int $deprecated Not used (Was $timezone = 0)
  */
 function trackback_rdf($deprecated = '') {
-	_deprecated_function( __FUNCTION__, '3.0' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0' );
 	return '';
 }
Index: wp-includes/formatting.php
===================================================================
--- wp-includes/formatting.php	(revision 1326)
+++ wp-includes/formatting.php	(working copy)
@@ -900,7 +900,7 @@
  */
 function convert_chars($content, $deprecated = '') {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.71' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '0.71' );
 
 	// Translation of invalid Unicode references range to valid range
 	$wp_htmltranswinuni = array(
@@ -1481,7 +1481,7 @@
  */
 function is_email( $email, $deprecated = false ) {
 	if ( ! empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '3.0' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0' );
 
 	// Test for the minimum length the email can be
 	if ( strlen( $email ) < 3 ) {
Index: wp-includes/general-template.php
===================================================================
--- wp-includes/general-template.php	(revision 1326)
+++ wp-includes/general-template.php	(working copy)
@@ -402,7 +402,7 @@
 	switch( $show ) {
 		case 'home' : // DEPRECATED
 		case 'siteurl' : // DEPRECATED
-			_deprecated_argument( __FUNCTION__, '2.2', sprintf( __('The <code>%s</code> option is deprecated for the family of <code>bloginfo()</code> functions.' ), $show ) . ' ' . sprintf( __( 'Use the <code>%s</code> option instead.' ), 'url'  ) );
+			_deprecated_argument( __FUNCTION__, 'wp-core', '2.2', sprintf( __('The <code>%s</code> option is deprecated for the family of <code>bloginfo()</code> functions.' ), $show ) . ' ' . sprintf( __( 'Use the <code>%s</code> option instead.' ), 'url'  ) );
 		case 'url' :
 			$output = home_url();
 			break;
@@ -462,7 +462,7 @@
 			$output = str_replace('_', '-', $output);
 			break;
 		case 'text_direction':
-			//_deprecated_argument( __FUNCTION__, '2.2', sprintf( __('The <code>%s</code> option is deprecated for the family of <code>bloginfo()</code> functions.' ), $show ) . ' ' . sprintf( __( 'Use the <code>%s</code> function instead.' ), 'is_rtl()'  ) );
+			//_deprecated_argument( __FUNCTION__, 'wp-core', '2.2', sprintf( __('The <code>%s</code> option is deprecated for the family of <code>bloginfo()</code> functions.' ), $show ) . ' ' . sprintf( __( 'Use the <code>%s</code> function instead.' ), 'is_rtl()'  ) );
 			if ( function_exists( 'is_rtl' ) ) {
 				$output = is_rtl() ? 'rtl' : 'ltr';
 			} else {
Index: wp-includes/kses.php
===================================================================
--- wp-includes/kses.php	(revision 1326)
+++ wp-includes/kses.php	(working copy)
@@ -1368,7 +1368,7 @@
  */
 function safecss_filter_attr( $css, $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.8.1' ); // Never implemented
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.8.1' ); // Never implemented
 
 	$css = wp_kses_no_null($css);
 	$css = str_replace(array("\n","\r","\t"), '', $css);
Index: wp-includes/l10n.php
===================================================================
--- wp-includes/l10n.php	(revision 1326)
+++ wp-includes/l10n.php	(working copy)
@@ -389,7 +389,7 @@
 	if ( false !== $plugin_rel_path	) {
 		$path = WP_PLUGIN_DIR . '/' . trim( $plugin_rel_path, '/' );
 	} else if ( false !== $abs_rel_path ) {
-		_deprecated_argument( __FUNCTION__, '2.7' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.7' );
 		$path = ABSPATH . trim( $abs_rel_path, '/' );
 	} else {
 		$path = WP_PLUGIN_DIR;
Index: wp-includes/link-template.php
===================================================================
--- wp-includes/link-template.php	(revision 1326)
+++ wp-includes/link-template.php	(working copy)
@@ -218,7 +218,7 @@
  */
 function post_permalink( $post_id = 0, $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '1.3' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '1.3' );
 
 	return get_permalink($post_id);
 }
@@ -846,7 +846,7 @@
  */
 function get_delete_post_link( $id = 0, $deprecated = '', $force_delete = false ) {
 	if ( ! empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '3.0.0' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0.0' );
 
 	if ( !$post = &get_post( $id ) )
 		return;
Index: wp-includes/load.php
===================================================================
--- wp-includes/load.php	(revision 1326)
+++ wp-includes/load.php	(working copy)
@@ -461,7 +461,7 @@
 
 	// Check for hacks file if the option is enabled
 	if ( get_option( 'hack_file' ) && file_exists( ABSPATH . 'my-hacks.php' ) ) {
-		_deprecated_file( 'my-hacks.php', '1.5' );
+		_deprecated_file( 'my-hacks.php', 'wp-core', '1.5' );
 		array_unshift( $plugins, ABSPATH . 'my-hacks.php' );
 	}
 
Index: wp-includes/ms-deprecated.php
===================================================================
--- wp-includes/ms-deprecated.php	(revision 1326)
+++ wp-includes/ms-deprecated.php	(working copy)
@@ -20,7 +20,7 @@
  * @see wp_generate_password()
  */
 function generate_random_password( $len = 8 ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'wp_generate_password()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'wp_generate_password()' );
 	return wp_generate_password( $len );
 }
 
@@ -41,7 +41,7 @@
  *
  */
 function is_site_admin( $user_login = '' ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'is_super_admin()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'is_super_admin()' );
 
 	if ( empty( $user_login ) ) {
 		$user_id = get_current_user_id();
@@ -65,7 +65,7 @@
  * @see wp_die()
  */
 function graceful_fail( $message ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'wp_die()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'wp_die()' );
 	$message = apply_filters( 'graceful_fail', $message );
 	$message_template = apply_filters( 'graceful_fail_template',
 '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
@@ -101,7 +101,7 @@
  * @deprecated Use $GLOBALS['current_user']->ID
  */
 function get_current_user_id() {
-	_deprecated_function( __FUNCTION__, '3.0', '$GLOBALS[\'current_user\']->ID' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', '$GLOBALS[\'current_user\']->ID' );
 	return $GLOBALS['current_user']->ID;
 }
 
@@ -112,7 +112,7 @@
  * @see get_user_by()
  */
 function get_user_details( $username ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'get_user_by()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'get_user_by()' );
 	return get_user_by('login', $username);
 }
 
@@ -123,7 +123,7 @@
  * @see clean_post_cache()
  */
 function clear_global_post_cache( $post_id ) {
-	_deprecated_function( __FUNCTION__, '3.0', 'clean_post_cache()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'clean_post_cache()' );
 }
 
 /**
@@ -133,7 +133,7 @@
  * @see is_main_site()
  */
 function is_main_blog() {
-	_deprecated_function( __FUNCTION__, '3.0', 'is_main_site()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'is_main_site()' );
 	return is_main_site();
 }
 
@@ -144,7 +144,7 @@
  * @see is_email()
  */
 function validate_email( $email, $check_domain = true) {
-	_deprecated_function( __FUNCTION__, '3.0', 'is_email()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'is_email()' );
 	return is_email( $email, $check_domain );
 }
 
Index: wp-includes/pluggable-deprecated.php
===================================================================
--- wp-includes/pluggable-deprecated.php	(revision 1326)
+++ wp-includes/pluggable-deprecated.php	(working copy)
@@ -31,7 +31,7 @@
  * @return object returns wp_set_current_user()
  */
 function set_current_user($id, $name = '') {
-	_deprecated_function( __FUNCTION__, '3.0', 'wp_set_current_user()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '3.0', 'wp_set_current_user()' );
 	return wp_set_current_user($id, $name);
 }
 endif;
@@ -53,7 +53,7 @@
  * @param bool $remember Optional. Remember that the user is logged in
  */
 function wp_setcookie($username, $password = '', $already_md5 = false, $home = '', $siteurl = '', $remember = false) {
-	_deprecated_function( __FUNCTION__, '2.5', 'wp_set_auth_cookie()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'wp_set_auth_cookie()' );
 	$user = get_userdatabylogin($username);
 	wp_set_auth_cookie($user->ID, $remember);
 }
@@ -71,7 +71,7 @@
  * @see wp_clear_auth_cookie()
  */
 function wp_clearcookie() {
-	_deprecated_function( __FUNCTION__, '2.5', 'wp_clear_auth_cookie()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'wp_clear_auth_cookie()' );
 	wp_clear_auth_cookie();
 }
 else :
@@ -92,7 +92,7 @@
  * @return bool Always returns false
  */
 function wp_get_cookie_login() {
-	_deprecated_function( __FUNCTION__, '2.5' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5' );
 	return false;
 }
 else :
@@ -120,7 +120,7 @@
  * @return bool False on login failure, true on successful check
  */
 function wp_login($username, $password, $deprecated = '') {
-	_deprecated_function( __FUNCTION__, '2.5', 'wp_signon()' );
+	_deprecated_function( __FUNCTION__, 'wp-core', '2.5', 'wp_signon()' );
 	global $error;
 
 	$user = wp_authenticate($username, $password);
Index: wp-includes/post-template.php
===================================================================
--- wp-includes/post-template.php	(revision 1326)
+++ wp-includes/post-template.php	(working copy)
@@ -250,7 +250,7 @@
  */
 function get_the_excerpt( $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.3' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.3' );
 
 	global $post;
 	$output = $post->post_excerpt;
@@ -923,7 +923,7 @@
  */
 function the_attachment_link( $id = 0, $fullsize = false, $deprecated = false, $permalink = false ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.5' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.5' );
 
 	if ( $fullsize )
 		echo wp_get_attachment_link($id, 'full', $permalink);
Index: wp-includes/registration-functions.php
===================================================================
--- wp-includes/registration-functions.php	(revision 1326)
+++ wp-includes/registration-functions.php	(working copy)
@@ -4,6 +4,6 @@
  *
  * @package WordPress
  */
-_deprecated_file( basename(__FILE__), '2.1', WPINC .  '/registration.php' );
+_deprecated_file( basename(__FILE__), 'wp-core', '2.1', WPINC .  '/registration.php' );
 require_once(ABSPATH . WPINC .  '/registration.php');
 ?>
Index: wp-includes/rss-functions.php
===================================================================
--- wp-includes/rss-functions.php	(revision 1326)
+++ wp-includes/rss-functions.php	(working copy)
@@ -5,6 +5,6 @@
  * @package WordPress
  */
 
-_deprecated_file( basename(__FILE__), '2.1', WPINC . '/rss.php' );
+_deprecated_file( basename(__FILE__), 'wp-core', '2.1', WPINC . '/rss.php' );
 require_once (ABSPATH . WPINC . '/rss.php');
 ?>
Index: wp-includes/rss.php
===================================================================
--- wp-includes/rss.php	(revision 1326)
+++ wp-includes/rss.php	(working copy)
@@ -15,7 +15,7 @@
 /**
  * Deprecated. Use SimplePie (class-simplepie.php) instead.
  */
-_deprecated_file( basename( __FILE__ ), '3.0', WPINC . '/class-simplepie.php' );
+_deprecated_file( basename( __FILE__ ), 'wp-core', '3.0', WPINC . '/class-simplepie.php' );
 
 /*
  * Hook to use another RSS object instead of MagpieRSS
Index: wp-includes/theme-compat/comments-popup.php
===================================================================
--- wp-includes/theme-compat/comments-popup.php	(revision 1326)
+++ wp-includes/theme-compat/comments-popup.php	(working copy)
@@ -7,7 +7,7 @@
  * This file is here for Backwards compatibility with old themes and will be removed in a future version
  * 
  */
-_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
+_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), 'wp-core', '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
 ?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
Index: wp-includes/theme-compat/comments.php
===================================================================
--- wp-includes/theme-compat/comments.php	(revision 1326)
+++ wp-includes/theme-compat/comments.php	(working copy)
@@ -7,7 +7,7 @@
  * This file is here for Backwards compatibility with old themes and will be removed in a future version
  * 
  */
-_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
+_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), 'wp-core', '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
 
 // Do not delete these lines
 	if (!empty($_SERVER['SCRIPT_FILENAME']) && 'comments.php' == basename($_SERVER['SCRIPT_FILENAME']))
Index: wp-includes/theme-compat/footer.php
===================================================================
--- wp-includes/theme-compat/footer.php	(revision 1326)
+++ wp-includes/theme-compat/footer.php	(working copy)
@@ -7,7 +7,7 @@
  * This file is here for Backwards compatibility with old themes and will be removed in a future version
  * 
  */
-_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
+_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), 'wp-core', '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
 ?>
 
 <hr />
Index: wp-includes/theme-compat/header.php
===================================================================
--- wp-includes/theme-compat/header.php	(revision 1326)
+++ wp-includes/theme-compat/header.php	(working copy)
@@ -7,7 +7,7 @@
  * This file is here for Backwards compatibility with old themes and will be removed in a future version
  * 
  */
-_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
+_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), 'wp-core', '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
Index: wp-includes/theme-compat/sidebar.php
===================================================================
--- wp-includes/theme-compat/sidebar.php	(revision 1326)
+++ wp-includes/theme-compat/sidebar.php	(working copy)
@@ -7,7 +7,7 @@
  * This file is here for Backwards compatibility with old themes and will be removed in a future version
  * 
  */
-_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
+_deprecated_file( sprintf( __( 'Theme without %1$s' ), basename(__FILE__) ), 'wp-core', '3.0', null, sprintf( __('Please include a %1$s template in your theme.'), basename(__FILE__) ) );
 ?>
 	<div id="sidebar" role="complementary">
 		<ul>
Index: wp-includes/user.php
===================================================================
--- wp-includes/user.php	(revision 1326)
+++ wp-includes/user.php	(working copy)
@@ -234,7 +234,7 @@
 	global $wpdb;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '3.0' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '3.0' );
 
 	if ( empty($user) ) {
 		$user = wp_get_current_user();
Index: wp-includes/widgets.php
===================================================================
--- wp-includes/widgets.php	(revision 1326)
+++ wp-includes/widgets.php	(working copy)
@@ -993,7 +993,7 @@
  */
 function wp_get_sidebars_widgets($deprecated = true) {
 	if ( $deprecated !== true )
-		_deprecated_argument( __FUNCTION__, '2.8.1' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.8.1' );
 
 	global $wp_registered_widgets, $wp_registered_sidebars, $_wp_sidebars_widgets;
 

Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 1326)
+++ wp-includes/functions.php	(working copy)
@@ -561,7 +561,7 @@
 	global $wpdb;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.3' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.3' );
 
 	$option = trim($option);
 	if ( empty($option) )
@@ -1300,7 +1300,7 @@
  */
 function wp_get_http_headers( $url, $deprecated = false ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.7' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.7' );
 
 	$response = wp_remote_head( $url );
 
@@ -2270,7 +2270,7 @@
  */
 function wp_upload_bits( $name, $deprecated, $bits, $time = null ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '2.0' );
+		_deprecated_argument( __FUNCTION__, 'wp-core', '2.0' );
 
 	if ( empty( $name ) )
 		return array( 'error' => __( 'Empty filename' ) );
@@ -3221,10 +3221,11 @@
  *   trigger or false to not trigger error.
  *
  * @param string $function The function that was called
  * @param string $version The version of WordPress that deprecated the function
  * @param string $replacement Optional. The function that should have been called
  */
-function _deprecated_function( $function, $version, $replacement=null ) {
+function _deprecated_function( $function, $package, $version, $replacement=null ) {
 
 	do_action( 'deprecated_function_run', $function, $replacement, $version );
 
@@ -3259,13 +3260,14 @@
  *   trigger or false to not trigger error.
  *
  * @param string $file The file that was included
  * @param string $version The version of WordPress that deprecated the file
  * @param string $replacement Optional. The file that should have been included based on ABSPATH
  * @param string $message Optional. A message regarding the change
  */
-function _deprecated_file( $file, $version, $replacement = null, $message = '' ) {
+function _deprecated_file( $file, $package, $version, $replacement = null, $message = '' ) {
 
-	do_action( 'deprecated_file_included', $file, $replacement, $version, $message );
+	do_action( 'deprecated_file_included', $file, $replacement, $package, $version, $message );
 
 	// Allow plugin to filter the output error trigger
 	if ( WP_DEBUG && apply_filters( 'deprecated_file_trigger_error', true ) ) {
@@ -3285,7 +3287,7 @@
  * For example:
  * <code>
  * if ( !empty($deprecated) )
- * 	_deprecated_argument( __FUNCTION__, '3.0' );
+ * 	_deprecated_argument( __FUNCTION__, 'wp-core', '3.0' );
  * </code>
  *
  * There is a hook deprecated_argument_run that will be called that can be used
@@ -3305,12 +3307,13 @@
  *   trigger or false to not trigger error.
  *
  * @param string $function The function that was called
  * @param string $version The version of WordPress that deprecated the argument used
  * @param string $message Optional. A message regarding the change.
  */
-function _deprecated_argument( $function, $version, $message = null ) {
+function _deprecated_argument( $function, $package, $version, $message = null ) {
 
-	do_action( 'deprecated_argument_run', $function, $message, $version );
+	do_action( 'deprecated_argument_run', $function, $message, $package, $version );
 
 	// Allow plugin to filter the output error trigger
 	if ( WP_DEBUG && apply_filters( 'deprecated_argument_trigger_error', true ) ) {
@@ -3221,10 +3221,11 @@
  *
  * @param string $function The function that was called
- * @param string $version The version of WordPress that deprecated the function
+ * @param string $package The package that $function belongs to
+ * @param string $version The version of $package that deprecated the function
  * @param string $replacement Optional. The function that should have been called
  */
@@ -3259,13 +3260,14 @@
  *
  * @param string $file The file that was included
- * @param string $version The version of WordPress that deprecated the file
+ * @param string $package The package that $function belongs to
+ * @param string $version The version of $package that deprecated the file
  * @param string $replacement Optional. The file that should have been included based on ABSPATH
  * @param string $message Optional. A message regarding the change
@@ -3305,12 +3307,13 @@
  *
  * @param string $function The function that was called
- * @param string $version The version of WordPress that deprecated the argument used
+ * @param string $package The package that $function belongs to
+ * @param string $version The version of $package that deprecated the argument used
  * @param string $message Optional. A message regarding the change.
  */